@@ -10,9 +10,12 @@
 	$fetch_last_error = false;
 	$fetch_last_error_code = false;
 	$fetch_last_content_type = false;
+	$fetch_last_error_content = false; // curl only for the time being
 	$fetch_curl_used = false;
 	$suppress_debugging = false;
 
+	libxml_disable_entity_loader(true);
+
 	mb_internal_encoding("UTF-8");
 	date_default_timezone_set('UTC');
 	if (defined('E_DEPRECATED')) {
@@ -63,6 +66,7 @@
 	function get_translations() {
 		$tr = array(
 					"auto"  => "Detect automatically",
+					"ar_SA" => "العربيّة (Arabic)",
 					"da_DA" => "Dansk",
 					"ca_CA" => "Català",
 					"cs_CZ" => "Česky",
@@ -348,16 +352,21 @@
 
 		global $fetch_last_error;
 		global $fetch_last_error_code;
+		global $fetch_last_error_content;
 		global $fetch_last_content_type;
 		global $fetch_curl_used;
 
+		$url = ltrim($url, ' ');
 		$url = str_replace(' ', '%20', $url);
 
+		if (strpos($url, "//") === 0)
+			$url = 'http:' . $url;
+
 		if (!defined('NO_CURL') && function_exists('curl_init')) {
 
 			$fetch_curl_used = true;
 
-			if (ini_get("safe_mode") || ini_get("open_basedir")) {
+			if (ini_get("safe_mode") || ini_get("open_basedir") || defined("FORCE_GETURL")) {
 				$new_url = geturl($url);
 				if (!$new_url) {
 				    // geturl has already populated $fetch_last_error
@@ -399,10 +408,6 @@
 				curl_setopt($ch, CURLOPT_POSTFIELDS, $post_query);
 			}
 
-			if ((OPENSSL_VERSION_NUMBER >= 0x0090808f) && (OPENSSL_VERSION_NUMBER < 0x10000000)) {
-				curl_setopt($ch, CURLOPT_SSLVERSION, 3);
-			}
-
 			if ($login && $pass)
 				curl_setopt($ch, CURLOPT_USERPWD, "$login:$pass");
 
@@ -430,6 +435,7 @@
 				} else {
 					$fetch_last_error = "HTTP Code: $http_code";
 				}
+				$fetch_last_error_content = $contents;
 				curl_close($ch);
 				return false;
 			}
@@ -1706,18 +1712,6 @@
 			$url = key($feedUrls);
 		}
 
-		/* libxml_use_internal_errors(true);
-		$doc = new DOMDocument();
-		$doc->loadXML($contents);
-		$error = libxml_get_last_error();
-		libxml_clear_errors();
-
-		if ($error) {
-			$error_message = format_libxml_error($error);
-
-			return array("code" => 6, "message" => $error_message);
-		} */
-
 		if ($cat_id == "0" || !$cat_id) {
 			$cat_qpart = "NULL";
 		} else {
@@ -1972,8 +1966,6 @@
 	function getFeedTitle($id, $cat = false) {
 		if ($cat) {
 			return getCategoryTitle($id);
-		} else if ($id == 0) {
-			return __("All feeds");
 		} else if ($id == -1) {
 			return __("Starred articles");
 		} else if ($id == -2) {
